% Constants OPX
R = 8.31446;
T = 1200+273;
P = 450e6;

% OPX Dislocation creep parameters (Lawlis, 1998)
ndisl = 2.9;                % dimensionless
Adisl = 6.92e8;
Qdisl = -600000;
Cdisl = exp(Qdisl./(R*T));
ACdisl = Cdisl*Adisl;

% OPX Diffusion creep parameters (Bruijn and Skemer, 2014)
pdif = -3;         %lawlis approach
ACdif = 1.9e-6;    %lawlis approach
%pdif = -2.49;       %piezo approach
%ACdif = 1.42e-6;    %piezo approach


% OPX Strain rate calculations.

% Calculations for small-grain-size half of deformation mechanism map
for d = 10:1000 %range effectively [1:100]
    for stress = 1:10000 %range effectively [0.1:1000]
        opxstrainrdisl(stress,d) = ACdisl*(stress/10).^ndisl*((d/10).^0);
        opxstrainrdif(stress,d) = ACdif*(stress/10)*(d/10).^pdif;
        opxstrainrtot(stress,d) = opxstrainrdisl(stress,d)+opxstrainrdif(stress,d);
    end
end

% Calculations for small-grain-size half of deformation mechanism map
figure
h=contour(opxstrainrtot,[1e-4 1e-6 1e-8 1e-10 1e-12],'-k','ShowText','off');
set(gca,'xscale','log')
set(gca,'yscale','log')
hold all
title('Opx def mech map at T = 1200 C and P = 450 MPa')
xlabel('d (\mum) x 0.1');
ylabel('\sigma (MPa) x 0.1');
axis([10 1000 1 10000]) %xaxis in reality [1:100], yaxis in reality [0.1:1000]
hold off

% Calculations for large-grain-size half of deformation mechanism map
for d = 10:1000 %range effectively [100:10000]
    for stress = 1:10000 %range effectively [0.1:1000]
        opxstrainrdisl(stress,d) = ACdisl*(stress/10).^ndisl*((d/0.1).^0);
        opxstrainrdif(stress,d) = ACdif*(stress/10)*(d/0.1).^pdif;
        opxstrainrtot(stress,d) = opxstrainrdisl(stress,d)+opxstrainrdif(stress,d);
    end
end

% Plotting large-grain-size half of orthopyroxene deformation mechanism map
figure
h=contour(opxstrainrtot,[1e-4 1e-6 1e-8 1e-10 1e-12],'-k','ShowText','off');
set(gca,'xscale','log')
set(gca,'yscale','log')
title('Large-grain-size half opx DMM at T = 1200 C and P = 450 MPa')
xlabel('d (\mum) x 10');
ylabel('\sigma (MPa) x 0.1');
axis([10 1000 1 10000]) %xaxis in reality [100:10000], yaxis in reality [0.1:1000]

% Calculation field boundary dislocation creep and diffusion creep for orthopyroxene
d = 1:10000;
difdis_opx = ((ACdif*(d.^pdif))/ACdisl).^(1/(ndisl-1));

% Calculating orthopyroxene grain-size piezometer after Linckens et al.
% (2014)
opxpiezostress = 2939.2*(d).^-1.308;

% Plotting Opx field boundary and grain-size piezometer in log grain-size -
% log stress parameter space of orthopyroxene deformation mechanism map
figure
set(gca,'xscale','log')
set(gca,'yscale','log')
hold all
plot(d,difdis_opx,'-r','LineWidth',2)
plot(d,opxpiezostress,'-g','LineWidth',2)
title('Opx field boundary and grain-size piezometer at T = 1200 C and P = 450 MPa')
xlabel('d (\mum)');
ylabel('\sigma (MPa)');
axis([1 10000 0.1 1000]) %xaxis in reality [1:10000], yaxis in reality [0.1:1000]

